@@ -3,7 +3,7 @@ from typing import List, Union, Dict, Optional
 from uuid import UUID
 
 from slapp_py.core_classes.division import Division
-from slapp_py.helpers.dict_helper import first_key
+from slapp_py.helpers.dict_helper import first_key, deserialize_uuids_into_list, serialize_uuids
 
 
 class DivisionsHandler:
@@ -27,18 +27,18 @@ class DivisionsHandler:
             return
         if not isinstance(incoming, list):
             incoming = [incoming]
-        if not isinstance(sources, list):
-            sources = [sources]
+
+        uuids = deserialize_uuids_into_list(sources)
 
         for to_add in incoming:
             if to_add.is_unknown:
                 continue
-            self._divs.setdefault(to_add, []).extend(sources)
+            self._divs.setdefault(to_add, []).extend(uuids)
 
     def filter_to_source(self, source_id: Union[str, UUID]) -> 'DivisionsHandler':
         search_uuid = source_id if isinstance(source_id, UUID) else UUID(source_id)
         return DivisionsHandler(
-            divs={k: v for k, v in self._divs if source_id in search_uuid}
+            divs={k: v for k, v in self._divs.items() if source_id in search_uuid}
         )
 
     def get_sources_for_division(self, div: Division) -> List[UUID]:
@@ -73,7 +73,7 @@ class DivisionsHandler:
     def to_dict(self) -> dict:
         result = {}
         if len(self._divs) > 0:
-            result["D"] = {k.__str__(): v for k, v in self._divs.items()}
+            result["D"] = {k.__str__(): serialize_uuids(v) for k, v in self._divs.items()}
         return result
 
     def __str__(self):
